import Model

extension Board {
    public func display(winCells: [Coords]) -> String {
        var str = String()
        
        for row in 0..<self.rows {
            for col in 0..<self.columns {
                let coord = Coords(col, row)
                
                let char = switch (self[coord]?.type, winCells.contains(coord)) {
                case (.A, false): "🔴"
                case (.A, true): "🟥"
                case (.B, false): "🟡"
                case (.B, true): "🟨"
                default: "⚪"
                }
                str += char
            }
            
            str += "\n"
        }
        
        return str
    }
}

extension Board: CustomStringConvertible, CustomDebugStringConvertible {
    public var description: String {
        self.display(winCells: [])
    }
    
    public var debugDescription: String {
        return "Board[\(self.columns)x\(self.rows), \(self.countPieces { p in p.type == .A }) A and \(self.countPieces { p in p.type == .B }) B pieces]"
    }
}


